@@ -5,9 +5,6 @@ processing.
 
 """
 
-# remove when we don't support py38 anymore
-from __future__ import annotations
-
 import logging
 from datetime import datetime
 from urllib.parse import urlsplit, urlunsplit
