@@ -1,9 +1,5 @@
 """Test the templates."""
 
-
-# remove when we don't support py38 anymore
-from __future__ import annotations
-
 import datetime
 
 from jinja2 import Template
