@@ -1,9 +1,5 @@
 """Test the version module."""
 
-
-# remove when we don't support py38 anymore
-from __future__ import annotations
-
 import blag
 
 
